@@ -582,7 +582,7 @@ class Score(Base):
 
 class Submission(Base):
     """
-    Отправленные работы задании
+    Результат сдачи задания студентом
     """
     __tablename__ = 'submissions'
 
@@ -799,6 +799,115 @@ class Submission(Base):
         return f'{self.score}'
 
 
+class QuizSubmission(Base):
+    """
+    Результат сдачи контрольной работы студентом
+    """
+    __tablename__ = 'quiz_submissions'
+
+    # Идентификатор
+    id = Column(Integer, primary_key=True)
+
+    # Контрольная работа
+    quiz_id = Column(ForeignKey('quizzes.id'))
+    quiz = relationship('Quiz')
+
+    # Версия контрольной работы (Неизвестно)
+    quiz_version = Column(Integer)
+
+    # Пользователь
+    user_id = Column(ForeignKey('users.id'))
+    user = relationship('User')
+
+    # Данные результата (В формате YAML)
+    submission_data = Column(String)
+
+    # Результат сдачи задания
+    # Когда студент сдает контрольную работу, он одновременно сдает и привязанную задание (Assignment)
+    # Поэтому как Quiz привязан к Assignment, так и quiz_submission привязан к submission
+    submission_id = Column(ForeignKey('submissions.id'))
+    submission = relationship('Submission')
+
+    # Оценка в виде числа
+    score = Column(Integer)
+
+    # Неизвестное значение (Но он обычно равен score)
+    kept_score = Column(Integer)
+
+    # Данные контрольной работы (В формате YAML)
+    # Здесь содержится данные контрольной работы (список вопросов и список ответов) на момент начатия
+    # работу студентом. Если преподаватель меняет содержимое теста во-время сдачи этим студентом, то у него
+    # ничего не меняется
+    quiz_data = Column(String)
+
+    # Когда студент начал работу
+    started_at = Column(DateTime)
+
+    # Когда работа закончена
+    end_at = Column(DateTime)
+
+    # Когда студент закончил работу
+    finished_at = Column(DateTime)
+
+    # Текущая попытка
+    attempt = Column(Integer)
+
+    # Статус работы
+    workflow_state = Column(String)
+
+    # Дата и время создания
+    created_at = Column(DateTime, server_default=func.now())
+
+    # Дата и время изменения
+    updated_at = Column(DateTIme, onupdate=func.now())
+
+    # Неизвестное значение
+    fudge_points = Column(Integer)
+
+    # Неизвестное значение (Возможно сколько максимум студент может набрать баллов)
+    quiz_points_possible = Column(Integer)
+
+    # Неизвестное значение (Возможно данные дополнительные попытки)
+    extra_attempts = Column(Integer)
+
+    # Неизвестное значение
+    temporary_user_code = Column(String)
+
+    # Неизвестное значение
+    extra_time = Column(Integer)
+
+    # Неизвестное значение
+    manually_unlocked = Column(Boolean)
+
+    # Неизвестное значение
+    manually_scored = Column(Boolean)
+
+    # Неизвестное значение
+    validation_token = Column(String)
+
+    # Неизвестное значение
+    score_before_regrade = Column(Integer)
+
+    # Неизвестное значение
+    was_preview = Column(Boolean)
+
+    # Неизвестное значение (Возможно обозначает видел ли студент свои результаты)
+    has_seen_results = Column(Boolean)
+
+    # Неизвестное значение
+    question_references_fixed = Column(Boolean)
+
+    # Корневая учетная запись
+    root_account_id = Column(ForeignKey('accounts.id'))
+    root_account = relationship('Account')
+
+    def __repr__(self):
+        return f'<QuizSubmission {self} (id={self.id} quiz_id={self.quiz_id} user_id={self.user_id})>'
+
+    def __str__(self):
+        return f'{self.score}'
+
+
 class GradingStandard(Base):
     """
     Стандарт оценки
@@ -2008,7 +2117,7 @@ class Quiz(Base):
         return f'<Quiz {self} (id={self.id} workflow_state={self.workflow_state})>'
 
     def __str__(self):
-        return f'{self.name}'
+        return f'{self.title}'
 
 
 class Enrollment(Base):
